@@ -13,7 +13,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.11_03'; # VERSION
+our $VERSION = '0.15_01'; # VERSION
 
 
 has timeout => (
@@ -62,30 +62,26 @@ sub connect
       url => $uri->as_string,
     );
     
-    my $stream = AnyEvent::WebSocket::Client::Stream->new(
-      handle => AnyEvent::Handle->new(
-                                                        fh       => $fh,
-        provided $uri->secure,                          tls      => 'connect',
-        provided $uri->secure && !$self->ssl_no_verify, peername => $uri->host,
-        provided $uri->secure && !$self->ssl_no_verify, tls_ctx  => {
-                                                                                       verify => 1,
-                                                                                       verify_peername => "https",
-                                                          provided $self->ssl_ca_file, ca_file => $self->ssl_ca_file,
-                                                        },
-                                                        on_error => sub {
-                                                          my ($hdl, $fatal, $msg) = @_;
-                                                          if($fatal)
-                                                          { $done->croak("connect error: " . $msg) }
-                                                          else
-                                                          { warn $msg }
-                                                        },
-      ),
+    my $hdl = AnyEvent::Handle->new(
+                                                      fh       => $fh,
+      provided $uri->secure,                          tls      => 'connect',
+      provided $uri->secure && !$self->ssl_no_verify, peername => $uri->host,
+      provided $uri->secure && !$self->ssl_no_verify, tls_ctx  => {
+                                                              verify => 1,
+                                                              verify_peername => "https",
+                                                        maybe ca_file => $self->ssl_ca_file,
+                                                      },
+                                                      on_error => sub {
+                                                        my ($hdl, $fatal, $msg) = @_;
+                                                        if($fatal)
+                                                        { $done->croak("connect error: " . $msg) }
+                                                        else
+                                                        { warn $msg }
+                                                      },
     );
-    my $hdl = $stream->handle;
     
     $hdl->push_write($handshake->to_string);
-
-    $stream->read_cb(sub {
+    $hdl->on_read(sub {
       $handshake->parse($_[0]{rbuf});
       if($handshake->error)
       {
@@ -93,52 +89,19 @@ sub connect
         undef $hdl;
         undef $handshake;
         undef $done;
-        undef $stream;
       }
       elsif($handshake->is_done)
       {
         undef $handshake;
-        $done->send(AnyEvent::WebSocket::Connection->new(
-          _stream => $stream,
-        ));
+        $done->send(AnyEvent::WebSocket::Connection->new(handle => $hdl));
         undef $hdl;
         undef $done;
-        undef $stream;
       }
-    });   
+    });
   }, sub { $self->timeout };
   $done;
 }
 
-package
-  AnyEvent::WebSocket::Client::Stream;
-
-use Moo;
-use warnings NONFATAL => 'all';
-use Scalar::Util qw( weaken );
-
-has handle => (
-  is       => 'ro',
-  required => 1,
-);
-
-has read_cb => (
-  is       => 'rw',
-  lazy     => 1,
-  default  => sub { sub { } },
-);
-
-sub BUILD
-{
-  my $self = shift;
-  weaken $self;
-  $self->handle->on_read(sub {
-    $self->handle->push_read(sub {
-      $self->read_cb->(@_) if $self->read_cb;
-    });
-  });
-}
-
 1;
 
 __END__
@@ -151,7 +114,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.11_03
+version 0.15_01
 
 =head1 SYNOPSIS
 
